# Slackware install script for exim
# 2004-02-17 Jaz Brown

config() {
    NEW="$1"
    OLD="`dirname $NEW`/`basename $NEW -sample`"
    # If there's no config file by that name, mv it over:
    if [ ! -r $OLD ]; then
        mv $NEW $OLD
    elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then
        # toss the redundant copy
        rm $NEW
    fi
    # Otherwise, we leave the -sample copy for the admin to consider...
}

config /etc/exim/configure-sample
config /etc/aliases-sample

# check if required user & groups exist; otherwise add them
# We'll try uing UID and GID 41, an error will result if these are in use already
if ! grep -q exim /etc/group; then
  groupadd -g 41 exim
fi
if ! grep -q exim /etc/passwd; then
  useradd -u 41 -g exim -d /var/spool/exim -c "The exim mail transfer agent" -s /bin/false exim
fi

# Make sure exim's SUID permissions haven't been removed from untarring
chmod 4755 /usr/sbin/exim-4.30-1

# Create exim's symlink
( cd usr/sbin ; rm -rf exim )
( cd usr/sbin ; ln -sf exim-4.30-1 exim )

# Create exim's log directory and make sure it is writable by exim
mkdir -p /var/log/exim
chown exim:exim /var/log/exim

# Add symlinks for sendmail compatability
if [ ! -f sendmail ]; then
  ln -sf exim sendmail
else
  echo "There is an old /usr/sbin/sendmail file present."
  echo "You may symlink exim to sendmail manually later."
fi
if [ ! -f mailq ]; then
  ln -sf exim mailq
else
  echo "There is an old /usr/sbin/mailq file present."
  echo "You may symlink exim to mailq manually later."
fi
if [ ! -f runq ]; then
  ln -sf exim runq
else
  echo "There is an old /usr/sbin/runq file present."
  echo "You may symlink exim to runq manually later."
fi

echo "Exim was installed in /usr/sbin"
echo "Exim's configuration file is: /etc/exim/configure"
echo "Exim will also use /etc/aliases"
echo "  Make sure it contains a real address for 'postmaster'"
echo "There's a startup script 'rc.exim' in /etc/rc.d"
echo "  Consider adding it to your rc.local script."
